Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4955)

Unified Diff: chrome/browser/chromeos/login/screens/network_error_view.h

Issue 2642823011: cros: Fold NetworkErrorModel into NetworkErrorView. (Closed)
Patch Set: Address comments Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/login/screens/network_error_view.h
diff --git a/chrome/browser/chromeos/login/screens/network_error_view.h b/chrome/browser/chromeos/login/screens/network_error_view.h
index 51d28cf2fb795f272c97c0d070b971a354dd0b1d..b58e3e3680eeaace3e00b2489cdf648d3e233692 100644
--- a/chrome/browser/chromeos/login/screens/network_error_view.h
+++ b/chrome/browser/chromeos/login/screens/network_error_view.h
@@ -10,7 +10,7 @@
namespace chromeos {
-class NetworkErrorModel;
+class ErrorScreen;
// Interface for dependency injection between ErrorScreen and its actual
// representation. Owned by ErrorScreen.
@@ -24,10 +24,10 @@ class NetworkErrorView {
// Hides the contents of the screen.
virtual void Hide() = 0;
- // Binds |model| to the view.
- virtual void Bind(NetworkErrorModel& model) = 0;
+ // Binds |screen| to the view.
+ virtual void Bind(ErrorScreen* screen) = 0;
- // Unbinds model from the view.
+ // Unbinds the screen from the view.
virtual void Unbind() = 0;
// Switches to |screen|.

Powered by Google App Engine
This is Rietveld 408576698